#
# spec file for package openocd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define external_jimtcl 0
%else
%define external_jimtcl 1
%endif

%define external_libjaylink 1

%define _udevdir %(pkg-config --variable udevdir udev)
Name:           openocd
Version:        0.12.0
Release:        2.5
Summary:        Debugging, in-system programming and boundary-scan testing for embedded devices
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
URL:            http://openocd.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
Source1:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2.sig
Source2:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2.sha256
Source3:        %name.keyring
BuildRequires:  autoconf >= 2.64
BuildRequires:  automake
BuildRequires:  fdupes
%if %{external_jimtcl}
BuildRequires:  jimtcl-devel
%endif
BuildRequires:  libftdi1-devel
BuildRequires:  libhidapi-devel
%if %{external_libjaylink}
BuildRequires:  libjaylink-devel >= 0.2.0
%endif
BuildRequires:  libtool
BuildRequires:  libusb-compat-devel
BuildRequires:  makeinfo
BuildRequires:  pkg-config >= 0.23
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
Requires:       %{name}-data = %{version}
Requires(post): udev
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}
Requires(postun):udev

%description
The Open On-Chip Debugger (OpenOCD) provides debugging, in-system programming
and boundary-scan testing for embedded devices.  Various different boards,
targets, and interfaces are supported to ease development time.

Install OpenOCD if you are looking for an open source solution for hardware
debugging.

%package data
Summary:        Hardware Scripts for OpenOCD
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
The Open On-Chip Debugger (OpenOCD) provides debugging, in-system programming
and boundary-scan testing for embedded devices.
This package provides hardware description files and documentation.

%prep
%setup -q

%build
%if !%{external_jimtcl}
# set this explicitly, else the configure from included jimtcl
# won't find a compiler :(
export CC=gcc
%endif
%configure \
  --disable-silent-rules \
  --disable-shared \
  --enable-static \
  --disable-doxygen-html \
  --disable-werror \
  --enable-ftdi \
  --enable-stlink \
  --enable-ti-icdi \
  --enable-ulink \
  --enable-usb-blaster-2 \
  --enable-vsllink \
  --enable-osbdm \
  --enable-opendous \
  --enable-aice \
  --enable-usbprog \
  --enable-rlink \
  --enable-armjtagew \
  --enable-cmsis-dap \
  --enable-usb-blaster \
  --enable-presto \
  --enable-openjtag \
  --enable-jlink \
%ifarch %ix86 x86_64
  --enable-parport \
%endif
  --enable-amtjtagaccel \
%ifarch %arm
  --enable-bcm2835gpio \
%endif
  --enable-gw16012 \
  --enable-buspirate \
  --enable-sysfsgpio \
%if %{external_jimtcl}
  --disable-internal-jimtcl \
%endif
%if %{external_libjaylink}
  --disable-internal-libjaylink \
%endif
  --enable-remote-bitbang \

make %{?_smp_mflags} V=1

%install
%make_install
rm -f %{buildroot}%{_infodir}/dir
rm -f %{buildroot}%{_libdir}/libopenocd.*
rm -f %{buildroot}%{_datadir}/%{name}/contrib/openocd.udev
rm -rf %{buildroot}%{_datadir}/%{name}/contrib/libdcc
mkdir -p %{buildroot}%{_udevdir}/rules.d
cat contrib/60-openocd.rules | sed -e 's/GROUP="plugdev"/GROUP="users"/' > %{buildroot}%{_udevdir}/rules.d/60-openocd.rules
%fdupes %{buildroot}

%post
%udev_rules_update
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%udev_rules_update

%files
%defattr(-,root,root,-)
%doc contrib/libdcc README AUTHORS ChangeLog COPYING NEWS
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_infodir}/%{name}.info*.gz
%{_udevdir}/rules.d/60-openocd.rules

%files data
%defattr(-,root,root,-)
%{_datadir}/%{name}

%changelog
* Fri Mar 17 2023 Torsten Duwe <duwe@suse.com>
- OpenOCD-0.12 requires a TCL jim version newer than the 0.75 which
  15.4 provides, so bump that version limit.
* Wed Jan 18 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 0.12.0
  The list of changes is massive, see
  https://sourceforge.net/p/openocd/code/ci/master/tree/NEWS-0.12.0
  for details.
* Tue Mar 23 2021 Philipp Wagner <mail@philipp-wagner.com>
- Update to upstream version 0.11.0.
  The list of changes is massive, see
  https://sourceforge.net/p/openocd/code/ci/master/tree/NEWS-0.11.0
  for details.
- libjaylink 0.2.0 is now required.
- Removed 0001-bitbang-Fix-FTBFS-with-GCC-10.patch patch.
- Use a source service to download sources.
* Sun Jun  7 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Add 0001-bitbang-Fix-FTBFS-with-GCC-10.patch: fix building for gcc 10
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through the -mini flavors.
* Sun Mar 19 2017 afaerber@suse.de
- Drop deprecated --enable-ioutil and --enable-oocd_trace options
- Sort and complement configure options
- Add back tarball signature
* Fri Mar 17 2017 afaerber@suse.de
- Update specfile for new libjaylink dependency
* Thu Mar 16 2017 opensuse@dstoecker.de
- update to 0.10.0
  * many updates: have a look in the log file
  /usr/share/doc/packages/openocd/NEWS
* Thu Jun 11 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * jtag/drivers/stlink: fix SRST issue with stlink-v1
  * nrf51: refine and extend known devices table
  * server: avoid the tcl server crashing when there is no target
  * manual: fix usb_blaster_pin command syntax and description
  * manual: reorder flash driver info
  * manual: remove the lists of config files
- point the source URL to sourceforge
- add source archive signature and author keyring
- add missing install_info_prereq as post and preun requires
- remove -n from %%setup: unnecessary
- call %%udev_rules_update instead of udevadm directly in post
  and postun: fix local build
- call %%install_info_delete in preun, not postun:
  fix scriptlet failed warning
* Sat Apr 25 2015 afaerber@suse.de
- Update to v0.9.0-rc1
  * Drop fix-jim_cmdproc.patch (fixed upstream)
  * Drop commented-out use of ./bootstrap script that doesn't exist
- Reorder adapter config options by configure.ac order
  * Fix misspelled config option arm-jtag-ew -> armjtagew
- Explicitly enable usb-blaster-2, usbprog
- Explicitly enable parport for x86 and bcm2835gpio for ARM
* Mon Oct  6 2014 matwey.kornilov@gmail.com
- Use libusb-compat instead of libusb0
* Tue May 13 2014 ralf@rdoering.net
- Update to openOCD 0.8 instead of git
- Build with external jimtcl only for factory, use included
  jimtcl for openSUSE 13.1 and older
- make it build with included jimtcl, so it builds for
  openSUSE 12.3 and 13.1
* Sat May 10 2014 matwey.kornilov@gmail.com
- Use spec_cleaner
* Sat Apr 26 2014 matwey.kornilov@gmail.com
- Drop not needed comments
* Sat Apr 19 2014 matwey.kornilov@gmail.com
- Provide COPYING file with the license.
* Thu Apr 10 2014 matwey.kornilov@gmail.com
- Drop url from source, as we use disabled-run _service
* Wed Apr  9 2014 matwey.kornilov@gmail.com
- openocd.udev has been renamed to 99-openocd.rules
* Sun Mar 23 2014 matwey.kornilov@gmail.com
- Add fix-jim_cmdproc.patch: jimtcl 0.75 has backward incompatibility
- Update to recent version
* Thu Mar 13 2014 matwey.kornilov@gmail.com
- add copyright handler to spec file
* Mon Jan 27 2014 matwey.kornilov@gmail.com
- remove Atmel SAMD20-XPRO patches
* Fri Dec 13 2013 matwey.kornilov@gmail.com
- add Atmel SAMD20-XPRO patches
* Fri Jul 12 2013 prusnak@opensuse.org
- created package based on Fedora package (version 0.7.0)
